@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,6 +15,8 @@
 #
 
 from .services.os_config_service import OsConfigServiceClient
+from .services.os_config_service import OsConfigServiceAsyncClient
+
 from .types.inventory import Inventory
 from .types.osconfig_common import FixedOrPercent
 from .types.patch_deployments import CreatePatchDeploymentRequest
@@ -51,8 +52,8 @@ from .types.patch_jobs import WindowsUpdateSettings
 from .types.patch_jobs import YumSettings
 from .types.patch_jobs import ZypperSettings
 
-
 __all__ = (
+    "OsConfigServiceAsyncClient",
     "AptSettings",
     "CancelPatchJobRequest",
     "CreatePatchDeploymentRequest",
@@ -75,6 +76,7 @@ __all__ = (
     "ListPatchJobsResponse",
     "MonthlySchedule",
     "OneTimeSchedule",
+    "OsConfigServiceClient",
     "PatchConfig",
     "PatchDeployment",
     "PatchInstanceFilter",
@@ -87,5 +89,4 @@ __all__ = (
     "WindowsUpdateSettings",
     "YumSettings",
     "ZypperSettings",
-    "OsConfigServiceClient",
 )
