@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -22,18 +20,17 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.osconfig_v1.services.os_config_service import pagers
 from google.cloud.osconfig_v1.types import patch_deployments
 from google.cloud.osconfig_v1.types import patch_jobs
-from google.protobuf import duration_pb2 as duration  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import duration_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import OsConfigServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import OsConfigServiceGrpcAsyncIOTransport
 from .client import OsConfigServiceClient
@@ -59,43 +56,67 @@ class OsConfigServiceAsyncClient:
     )
     patch_job_path = staticmethod(OsConfigServiceClient.patch_job_path)
     parse_patch_job_path = staticmethod(OsConfigServiceClient.parse_patch_job_path)
-
     common_billing_account_path = staticmethod(
         OsConfigServiceClient.common_billing_account_path
     )
     parse_common_billing_account_path = staticmethod(
         OsConfigServiceClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(OsConfigServiceClient.common_folder_path)
     parse_common_folder_path = staticmethod(
         OsConfigServiceClient.parse_common_folder_path
     )
-
     common_organization_path = staticmethod(
         OsConfigServiceClient.common_organization_path
     )
     parse_common_organization_path = staticmethod(
         OsConfigServiceClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(OsConfigServiceClient.common_project_path)
     parse_common_project_path = staticmethod(
         OsConfigServiceClient.parse_common_project_path
     )
-
     common_location_path = staticmethod(OsConfigServiceClient.common_location_path)
     parse_common_location_path = staticmethod(
         OsConfigServiceClient.parse_common_location_path
     )
 
-    from_service_account_info = OsConfigServiceClient.from_service_account_info
-    from_service_account_file = OsConfigServiceClient.from_service_account_file
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            OsConfigServiceAsyncClient: The constructed client.
+        """
+        return OsConfigServiceClient.from_service_account_info.__func__(OsConfigServiceAsyncClient, info, *args, **kwargs)  # type: ignore
+
+    @classmethod
+    def from_service_account_file(cls, filename: str, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            file.
+
+        Args:
+            filename (str): The path to the service account private key json
+                file.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            OsConfigServiceAsyncClient: The constructed client.
+        """
+        return OsConfigServiceClient.from_service_account_file.__func__(OsConfigServiceAsyncClient, filename, *args, **kwargs)  # type: ignore
+
     from_service_account_json = from_service_account_file
 
     @property
     def transport(self) -> OsConfigServiceTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             OsConfigServiceTransport: The transport used by the client instance.
@@ -109,12 +130,12 @@ class OsConfigServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, OsConfigServiceTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the os config service client.
+        """Instantiates the os config service client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -146,7 +167,6 @@ class OsConfigServiceAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = OsConfigServiceClient(
             credentials=credentials,
             transport=transport,
@@ -166,10 +186,9 @@ class OsConfigServiceAsyncClient:
         job.
 
         Args:
-            request (:class:`~.patch_jobs.ExecutePatchJobRequest`):
+            request (:class:`google.cloud.osconfig_v1.types.ExecutePatchJobRequest`):
                 The request object. A request message to initiate
                 patching across Compute Engine instances.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -177,21 +196,20 @@ class OsConfigServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.patch_jobs.PatchJob:
-                A high level representation of a patch job that is
-                either in progress or has completed.
+            google.cloud.osconfig_v1.types.PatchJob:
+                A high level representation of a patch job that is either in progress
+                   or has completed.
 
-                Instance details are not included in the job. To
-                paginate through instance details, use
-                ListPatchJobInstanceDetails.
+                   Instance details are not included in the job. To
+                   paginate through instance details, use
+                   ListPatchJobInstanceDetails.
 
-                For more information about patch jobs, see `Creating
-                patch
-                jobs <https://cloud.google.com/compute/docs/os-patch-management/create-patch-job>`__.
+                   For more information about patch jobs, see [Creating
+                   patch
+                   jobs](\ https://cloud.google.com/compute/docs/os-patch-management/create-patch-job).
 
         """
         # Create or coerce a protobuf request object.
-
         request = patch_jobs.ExecutePatchJobRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -228,16 +246,16 @@ class OsConfigServiceAsyncClient:
         of completed jobs.
 
         Args:
-            request (:class:`~.patch_jobs.GetPatchJobRequest`):
+            request (:class:`google.cloud.osconfig_v1.types.GetPatchJobRequest`):
                 The request object. Request to get an active or
                 completed patch job.
             name (:class:`str`):
                 Required. Name of the patch in the form
                 ``projects/*/patchJobs/*``
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -245,17 +263,17 @@ class OsConfigServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.patch_jobs.PatchJob:
-                A high level representation of a patch job that is
-                either in progress or has completed.
+            google.cloud.osconfig_v1.types.PatchJob:
+                A high level representation of a patch job that is either in progress
+                   or has completed.
 
-                Instance details are not included in the job. To
-                paginate through instance details, use
-                ListPatchJobInstanceDetails.
+                   Instance details are not included in the job. To
+                   paginate through instance details, use
+                   ListPatchJobInstanceDetails.
 
-                For more information about patch jobs, see `Creating
-                patch
-                jobs <https://cloud.google.com/compute/docs/os-patch-management/create-patch-job>`__.
+                   For more information about patch jobs, see [Creating
+                   patch
+                   jobs](\ https://cloud.google.com/compute/docs/os-patch-management/create-patch-job).
 
         """
         # Create or coerce a protobuf request object.
@@ -272,7 +290,6 @@ class OsConfigServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -308,9 +325,8 @@ class OsConfigServiceAsyncClient:
         Canceled patch jobs cannot be restarted.
 
         Args:
-            request (:class:`~.patch_jobs.CancelPatchJobRequest`):
+            request (:class:`google.cloud.osconfig_v1.types.CancelPatchJobRequest`):
                 The request object. Message for canceling a patch job.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -318,21 +334,20 @@ class OsConfigServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.patch_jobs.PatchJob:
-                A high level representation of a patch job that is
-                either in progress or has completed.
+            google.cloud.osconfig_v1.types.PatchJob:
+                A high level representation of a patch job that is either in progress
+                   or has completed.
 
-                Instance details are not included in the job. To
-                paginate through instance details, use
-                ListPatchJobInstanceDetails.
+                   Instance details are not included in the job. To
+                   paginate through instance details, use
+                   ListPatchJobInstanceDetails.
 
-                For more information about patch jobs, see `Creating
-                patch
-                jobs <https://cloud.google.com/compute/docs/os-patch-management/create-patch-job>`__.
+                   For more information about patch jobs, see [Creating
+                   patch
+                   jobs](\ https://cloud.google.com/compute/docs/os-patch-management/create-patch-job).
 
         """
         # Create or coerce a protobuf request object.
-
         request = patch_jobs.CancelPatchJobRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -367,7 +382,7 @@ class OsConfigServiceAsyncClient:
         r"""Get a list of patch jobs.
 
         Args:
-            request (:class:`~.patch_jobs.ListPatchJobsRequest`):
+            request (:class:`google.cloud.osconfig_v1.types.ListPatchJobsRequest`):
                 The request object. A request message for listing patch
                 jobs.
             parent (:class:`str`):
@@ -375,7 +390,6 @@ class OsConfigServiceAsyncClient:
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -383,7 +397,7 @@ class OsConfigServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListPatchJobsAsyncPager:
+            google.cloud.osconfig_v1.services.os_config_service.pagers.ListPatchJobsAsyncPager:
                 A response message for listing patch
                 jobs.
                 Iterating over this object will yield
@@ -405,7 +419,6 @@ class OsConfigServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
 
@@ -447,16 +460,16 @@ class OsConfigServiceAsyncClient:
         r"""Get a list of instance details for a given patch job.
 
         Args:
-            request (:class:`~.patch_jobs.ListPatchJobInstanceDetailsRequest`):
+            request (:class:`google.cloud.osconfig_v1.types.ListPatchJobInstanceDetailsRequest`):
                 The request object. Request to list details for all
                 instances that are part of a patch job.
             parent (:class:`str`):
                 Required. The parent for the instances are in the form
                 of ``projects/*/patchJobs/*``.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -464,7 +477,7 @@ class OsConfigServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListPatchJobInstanceDetailsAsyncPager:
+            google.cloud.osconfig_v1.services.os_config_service.pagers.ListPatchJobInstanceDetailsAsyncPager:
                 A response message for listing the
                 instances details for a patch job.
                 Iterating over this object will yield
@@ -486,7 +499,6 @@ class OsConfigServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
 
@@ -530,18 +542,20 @@ class OsConfigServiceAsyncClient:
         r"""Create an OS Config patch deployment.
 
         Args:
-            request (:class:`~.patch_deployments.CreatePatchDeploymentRequest`):
+            request (:class:`google.cloud.osconfig_v1.types.CreatePatchDeploymentRequest`):
                 The request object. A request message for creating a
                 patch deployment.
             parent (:class:`str`):
                 Required. The project to apply this patch deployment to
                 in the form ``projects/*``.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            patch_deployment (:class:`~.patch_deployments.PatchDeployment`):
+            patch_deployment (:class:`google.cloud.osconfig_v1.types.PatchDeployment`):
                 Required. The patch deployment to
                 create.
+
                 This corresponds to the ``patch_deployment`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -556,10 +570,10 @@ class OsConfigServiceAsyncClient:
                 -  Must end with a number or a letter.
                 -  Must be unique within the project.
 
+
                 This corresponds to the ``patch_deployment_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -567,13 +581,13 @@ class OsConfigServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.patch_deployments.PatchDeployment:
-                Patch deployments are configurations that individual
-                patch jobs use to complete a patch. These configurations
-                include instance filter, package repository settings,
-                and a schedule. For more information about creating and
-                managing patch deployments, see `Scheduling patch
-                jobs <https://cloud.google.com/compute/docs/os-patch-management/schedule-patch-jobs>`__.
+            google.cloud.osconfig_v1.types.PatchDeployment:
+                Patch deployments are configurations that individual patch jobs use to
+                   complete a patch. These configurations include
+                   instance filter, package repository settings, and a
+                   schedule. For more information about creating and
+                   managing patch deployments, see [Scheduling patch
+                   jobs](\ https://cloud.google.com/compute/docs/os-patch-management/schedule-patch-jobs).
 
         """
         # Create or coerce a protobuf request object.
@@ -590,7 +604,6 @@ class OsConfigServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
         if patch_deployment is not None:
@@ -630,16 +643,16 @@ class OsConfigServiceAsyncClient:
         r"""Get an OS Config patch deployment.
 
         Args:
-            request (:class:`~.patch_deployments.GetPatchDeploymentRequest`):
+            request (:class:`google.cloud.osconfig_v1.types.GetPatchDeploymentRequest`):
                 The request object. A request message for retrieving a
                 patch deployment.
             name (:class:`str`):
                 Required. The resource name of the patch deployment in
                 the form ``projects/*/patchDeployments/*``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -647,13 +660,13 @@ class OsConfigServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.patch_deployments.PatchDeployment:
-                Patch deployments are configurations that individual
-                patch jobs use to complete a patch. These configurations
-                include instance filter, package repository settings,
-                and a schedule. For more information about creating and
-                managing patch deployments, see `Scheduling patch
-                jobs <https://cloud.google.com/compute/docs/os-patch-management/schedule-patch-jobs>`__.
+            google.cloud.osconfig_v1.types.PatchDeployment:
+                Patch deployments are configurations that individual patch jobs use to
+                   complete a patch. These configurations include
+                   instance filter, package repository settings, and a
+                   schedule. For more information about creating and
+                   managing patch deployments, see [Scheduling patch
+                   jobs](\ https://cloud.google.com/compute/docs/os-patch-management/schedule-patch-jobs).
 
         """
         # Create or coerce a protobuf request object.
@@ -670,7 +683,6 @@ class OsConfigServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -706,16 +718,16 @@ class OsConfigServiceAsyncClient:
         r"""Get a page of OS Config patch deployments.
 
         Args:
-            request (:class:`~.patch_deployments.ListPatchDeploymentsRequest`):
+            request (:class:`google.cloud.osconfig_v1.types.ListPatchDeploymentsRequest`):
                 The request object. A request message for listing patch
                 deployments.
             parent (:class:`str`):
                 Required. The resource name of the parent in the form
                 ``projects/*``.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -723,7 +735,7 @@ class OsConfigServiceAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListPatchDeploymentsAsyncPager:
+            google.cloud.osconfig_v1.services.os_config_service.pagers.ListPatchDeploymentsAsyncPager:
                 A response message for listing patch
                 deployments.
                 Iterating over this object will yield
@@ -745,7 +757,6 @@ class OsConfigServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
 
@@ -787,16 +798,16 @@ class OsConfigServiceAsyncClient:
         r"""Delete an OS Config patch deployment.
 
         Args:
-            request (:class:`~.patch_deployments.DeletePatchDeploymentRequest`):
+            request (:class:`google.cloud.osconfig_v1.types.DeletePatchDeploymentRequest`):
                 The request object. A request message for deleting a
                 patch deployment.
             name (:class:`str`):
                 Required. The resource name of the patch deployment in
                 the form ``projects/*/patchDeployments/*``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -817,7 +828,6 @@ class OsConfigServiceAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
