@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -35,9 +33,8 @@ from google.oauth2 import service_account  # type: ignore
 from google.cloud.osconfig_v1.services.os_config_service import pagers
 from google.cloud.osconfig_v1.types import patch_deployments
 from google.cloud.osconfig_v1.types import patch_jobs
-from google.protobuf import duration_pb2 as duration  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import duration_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import OsConfigServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import OsConfigServiceGrpcTransport
 from .transports.grpc_asyncio import OsConfigServiceGrpcAsyncIOTransport
@@ -58,7 +55,7 @@ class OsConfigServiceClientMeta(type):
     _transport_registry["grpc_asyncio"] = OsConfigServiceGrpcAsyncIOTransport
 
     def get_transport_class(cls, label: str = None,) -> Type[OsConfigServiceTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -85,7 +82,8 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -119,7 +117,8 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -127,7 +126,7 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
             kwargs: Additional arguments to pass to the constructor.
 
         Returns:
-            {@api.name}: The constructed client.
+            OsConfigServiceClient: The constructed client.
         """
         credentials = service_account.Credentials.from_service_account_info(info)
         kwargs["credentials"] = credentials
@@ -136,7 +135,7 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -145,7 +144,7 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
             kwargs: Additional arguments to pass to the constructor.
 
         Returns:
-            {@api.name}: The constructed client.
+            OsConfigServiceClient: The constructed client.
         """
         credentials = service_account.Credentials.from_service_account_file(filename)
         kwargs["credentials"] = credentials
@@ -155,23 +154,24 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
     @property
     def transport(self) -> OsConfigServiceTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
-            OsConfigServiceTransport: The transport used by the client instance.
+            OsConfigServiceTransport: The transport used by the client
+                instance.
         """
         return self._transport
 
     @staticmethod
     def instance_path(project: str, zone: str, instance: str,) -> str:
-        """Return a fully-qualified instance string."""
+        """Returns a fully-qualified instance string."""
         return "projects/{project}/zones/{zone}/instances/{instance}".format(
             project=project, zone=zone, instance=instance,
         )
 
     @staticmethod
     def parse_instance_path(path: str) -> Dict[str, str]:
-        """Parse a instance path into its component segments."""
+        """Parses a instance path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/zones/(?P<zone>.+?)/instances/(?P<instance>.+?)$",
             path,
@@ -180,14 +180,14 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
     @staticmethod
     def patch_deployment_path(project: str, patch_deployment: str,) -> str:
-        """Return a fully-qualified patch_deployment string."""
+        """Returns a fully-qualified patch_deployment string."""
         return "projects/{project}/patchDeployments/{patch_deployment}".format(
             project=project, patch_deployment=patch_deployment,
         )
 
     @staticmethod
     def parse_patch_deployment_path(path: str) -> Dict[str, str]:
-        """Parse a patch_deployment path into its component segments."""
+        """Parses a patch_deployment path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/patchDeployments/(?P<patch_deployment>.+?)$",
             path,
@@ -196,20 +196,20 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
     @staticmethod
     def patch_job_path(project: str, patch_job: str,) -> str:
-        """Return a fully-qualified patch_job string."""
+        """Returns a fully-qualified patch_job string."""
         return "projects/{project}/patchJobs/{patch_job}".format(
             project=project, patch_job=patch_job,
         )
 
     @staticmethod
     def parse_patch_job_path(path: str) -> Dict[str, str]:
-        """Parse a patch_job path into its component segments."""
+        """Parses a patch_job path into its component segments."""
         m = re.match(r"^projects/(?P<project>.+?)/patchJobs/(?P<patch_job>.+?)$", path)
         return m.groupdict() if m else {}
 
     @staticmethod
     def common_billing_account_path(billing_account: str,) -> str:
-        """Return a fully-qualified billing_account string."""
+        """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
         )
@@ -222,7 +222,7 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
     @staticmethod
     def common_folder_path(folder: str,) -> str:
-        """Return a fully-qualified folder string."""
+        """Returns a fully-qualified folder string."""
         return "folders/{folder}".format(folder=folder,)
 
     @staticmethod
@@ -233,7 +233,7 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
     @staticmethod
     def common_organization_path(organization: str,) -> str:
-        """Return a fully-qualified organization string."""
+        """Returns a fully-qualified organization string."""
         return "organizations/{organization}".format(organization=organization,)
 
     @staticmethod
@@ -244,7 +244,7 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
     @staticmethod
     def common_project_path(project: str,) -> str:
-        """Return a fully-qualified project string."""
+        """Returns a fully-qualified project string."""
         return "projects/{project}".format(project=project,)
 
     @staticmethod
@@ -255,7 +255,7 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
 
     @staticmethod
     def common_location_path(project: str, location: str,) -> str:
-        """Return a fully-qualified location string."""
+        """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
             project=project, location=location,
         )
@@ -269,12 +269,12 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, OsConfigServiceTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the os config service client.
+        """Instantiates the os config service client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -282,10 +282,10 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
                 credentials identify the application to the service; if none
                 are specified, the client will attempt to ascertain the
                 credentials from the environment.
-            transport (Union[str, ~.OsConfigServiceTransport]): The
+            transport (Union[str, OsConfigServiceTransport]): The
                 transport to use. If set to None, a transport is chosen
                 automatically.
-            client_options (client_options_lib.ClientOptions): Custom options for the
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -321,21 +321,18 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
             util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
         )
 
-        ssl_credentials = None
+        client_cert_source_func = None
         is_mtls = False
         if use_client_cert:
             if client_options.client_cert_source:
-                import grpc  # type: ignore
-
-                cert, key = client_options.client_cert_source()
-                ssl_credentials = grpc.ssl_channel_credentials(
-                    certificate_chain=cert, private_key=key
-                )
                 is_mtls = True
+                client_cert_source_func = client_options.client_cert_source
             else:
-                creds = SslCredentials()
-                is_mtls = creds.is_mtls
-                ssl_credentials = creds.ssl_credentials if is_mtls else None
+                is_mtls = mtls.has_default_client_cert_source()
+                if is_mtls:
+                    client_cert_source_func = mtls.default_client_cert_source()
+                else:
+                    client_cert_source_func = None
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -347,12 +344,14 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
             elif use_mtls_env == "always":
                 api_endpoint = self.DEFAULT_MTLS_ENDPOINT
             elif use_mtls_env == "auto":
-                api_endpoint = (
-                    self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
-                )
+                if is_mtls:
+                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+                else:
+                    api_endpoint = self.DEFAULT_ENDPOINT
             else:
                 raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
+                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
+                    "values: never, auto, always"
                 )
 
         # Save or instantiate the transport.
@@ -367,8 +366,8 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
                 )
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
@@ -378,7 +377,7 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
                 credentials_file=client_options.credentials_file,
                 host=api_endpoint,
                 scopes=client_options.scopes,
-                ssl_channel_credentials=ssl_credentials,
+                client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
             )
@@ -395,10 +394,9 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         job.
 
         Args:
-            request (:class:`~.patch_jobs.ExecutePatchJobRequest`):
+            request (google.cloud.osconfig_v1.types.ExecutePatchJobRequest):
                 The request object. A request message to initiate
                 patching across Compute Engine instances.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -406,21 +404,20 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.patch_jobs.PatchJob:
-                A high level representation of a patch job that is
-                either in progress or has completed.
+            google.cloud.osconfig_v1.types.PatchJob:
+                A high level representation of a patch job that is either in progress
+                   or has completed.
 
-                Instance details are not included in the job. To
-                paginate through instance details, use
-                ListPatchJobInstanceDetails.
+                   Instance details are not included in the job. To
+                   paginate through instance details, use
+                   ListPatchJobInstanceDetails.
 
-                For more information about patch jobs, see `Creating
-                patch
-                jobs <https://cloud.google.com/compute/docs/os-patch-management/create-patch-job>`__.
+                   For more information about patch jobs, see [Creating
+                   patch
+                   jobs](\ https://cloud.google.com/compute/docs/os-patch-management/create-patch-job).
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a patch_jobs.ExecutePatchJobRequest.
         # There's no risk of modifying the input as we've already verified
@@ -458,16 +455,16 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         of completed jobs.
 
         Args:
-            request (:class:`~.patch_jobs.GetPatchJobRequest`):
+            request (google.cloud.osconfig_v1.types.GetPatchJobRequest):
                 The request object. Request to get an active or
                 completed patch job.
-            name (:class:`str`):
+            name (str):
                 Required. Name of the patch in the form
                 ``projects/*/patchJobs/*``
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -475,17 +472,17 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.patch_jobs.PatchJob:
-                A high level representation of a patch job that is
-                either in progress or has completed.
+            google.cloud.osconfig_v1.types.PatchJob:
+                A high level representation of a patch job that is either in progress
+                   or has completed.
 
-                Instance details are not included in the job. To
-                paginate through instance details, use
-                ListPatchJobInstanceDetails.
+                   Instance details are not included in the job. To
+                   paginate through instance details, use
+                   ListPatchJobInstanceDetails.
 
-                For more information about patch jobs, see `Creating
-                patch
-                jobs <https://cloud.google.com/compute/docs/os-patch-management/create-patch-job>`__.
+                   For more information about patch jobs, see [Creating
+                   patch
+                   jobs](\ https://cloud.google.com/compute/docs/os-patch-management/create-patch-job).
 
         """
         # Create or coerce a protobuf request object.
@@ -504,10 +501,8 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, patch_jobs.GetPatchJobRequest):
             request = patch_jobs.GetPatchJobRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -539,9 +534,8 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         Canceled patch jobs cannot be restarted.
 
         Args:
-            request (:class:`~.patch_jobs.CancelPatchJobRequest`):
+            request (google.cloud.osconfig_v1.types.CancelPatchJobRequest):
                 The request object. Message for canceling a patch job.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -549,21 +543,20 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.patch_jobs.PatchJob:
-                A high level representation of a patch job that is
-                either in progress or has completed.
+            google.cloud.osconfig_v1.types.PatchJob:
+                A high level representation of a patch job that is either in progress
+                   or has completed.
 
-                Instance details are not included in the job. To
-                paginate through instance details, use
-                ListPatchJobInstanceDetails.
+                   Instance details are not included in the job. To
+                   paginate through instance details, use
+                   ListPatchJobInstanceDetails.
 
-                For more information about patch jobs, see `Creating
-                patch
-                jobs <https://cloud.google.com/compute/docs/os-patch-management/create-patch-job>`__.
+                   For more information about patch jobs, see [Creating
+                   patch
+                   jobs](\ https://cloud.google.com/compute/docs/os-patch-management/create-patch-job).
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a patch_jobs.CancelPatchJobRequest.
         # There's no risk of modifying the input as we've already verified
@@ -599,15 +592,14 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         r"""Get a list of patch jobs.
 
         Args:
-            request (:class:`~.patch_jobs.ListPatchJobsRequest`):
+            request (google.cloud.osconfig_v1.types.ListPatchJobsRequest):
                 The request object. A request message for listing patch
                 jobs.
-            parent (:class:`str`):
+            parent (str):
                 Required. In the form of ``projects/*``
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -615,7 +607,7 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListPatchJobsPager:
+            google.cloud.osconfig_v1.services.os_config_service.pagers.ListPatchJobsPager:
                 A response message for listing patch
                 jobs.
                 Iterating over this object will yield
@@ -639,10 +631,8 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, patch_jobs.ListPatchJobsRequest):
             request = patch_jobs.ListPatchJobsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -680,16 +670,16 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         r"""Get a list of instance details for a given patch job.
 
         Args:
-            request (:class:`~.patch_jobs.ListPatchJobInstanceDetailsRequest`):
+            request (google.cloud.osconfig_v1.types.ListPatchJobInstanceDetailsRequest):
                 The request object. Request to list details for all
                 instances that are part of a patch job.
-            parent (:class:`str`):
+            parent (str):
                 Required. The parent for the instances are in the form
                 of ``projects/*/patchJobs/*``.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -697,7 +687,7 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListPatchJobInstanceDetailsPager:
+            google.cloud.osconfig_v1.services.os_config_service.pagers.ListPatchJobInstanceDetailsPager:
                 A response message for listing the
                 instances details for a patch job.
                 Iterating over this object will yield
@@ -721,10 +711,8 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, patch_jobs.ListPatchJobInstanceDetailsRequest):
             request = patch_jobs.ListPatchJobInstanceDetailsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -766,22 +754,24 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         r"""Create an OS Config patch deployment.
 
         Args:
-            request (:class:`~.patch_deployments.CreatePatchDeploymentRequest`):
+            request (google.cloud.osconfig_v1.types.CreatePatchDeploymentRequest):
                 The request object. A request message for creating a
                 patch deployment.
-            parent (:class:`str`):
+            parent (str):
                 Required. The project to apply this patch deployment to
                 in the form ``projects/*``.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            patch_deployment (:class:`~.patch_deployments.PatchDeployment`):
+            patch_deployment (google.cloud.osconfig_v1.types.PatchDeployment):
                 Required. The patch deployment to
                 create.
+
                 This corresponds to the ``patch_deployment`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            patch_deployment_id (:class:`str`):
+            patch_deployment_id (str):
                 Required. A name for the patch deployment in the
                 project. When creating a name the following rules apply:
 
@@ -792,10 +782,10 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
                 -  Must end with a number or a letter.
                 -  Must be unique within the project.
 
+
                 This corresponds to the ``patch_deployment_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -803,13 +793,13 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.patch_deployments.PatchDeployment:
-                Patch deployments are configurations that individual
-                patch jobs use to complete a patch. These configurations
-                include instance filter, package repository settings,
-                and a schedule. For more information about creating and
-                managing patch deployments, see `Scheduling patch
-                jobs <https://cloud.google.com/compute/docs/os-patch-management/schedule-patch-jobs>`__.
+            google.cloud.osconfig_v1.types.PatchDeployment:
+                Patch deployments are configurations that individual patch jobs use to
+                   complete a patch. These configurations include
+                   instance filter, package repository settings, and a
+                   schedule. For more information about creating and
+                   managing patch deployments, see [Scheduling patch
+                   jobs](\ https://cloud.google.com/compute/docs/os-patch-management/schedule-patch-jobs).
 
         """
         # Create or coerce a protobuf request object.
@@ -828,10 +818,8 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, patch_deployments.CreatePatchDeploymentRequest):
             request = patch_deployments.CreatePatchDeploymentRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if patch_deployment is not None:
@@ -867,16 +855,16 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         r"""Get an OS Config patch deployment.
 
         Args:
-            request (:class:`~.patch_deployments.GetPatchDeploymentRequest`):
+            request (google.cloud.osconfig_v1.types.GetPatchDeploymentRequest):
                 The request object. A request message for retrieving a
                 patch deployment.
-            name (:class:`str`):
+            name (str):
                 Required. The resource name of the patch deployment in
                 the form ``projects/*/patchDeployments/*``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -884,13 +872,13 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.patch_deployments.PatchDeployment:
-                Patch deployments are configurations that individual
-                patch jobs use to complete a patch. These configurations
-                include instance filter, package repository settings,
-                and a schedule. For more information about creating and
-                managing patch deployments, see `Scheduling patch
-                jobs <https://cloud.google.com/compute/docs/os-patch-management/schedule-patch-jobs>`__.
+            google.cloud.osconfig_v1.types.PatchDeployment:
+                Patch deployments are configurations that individual patch jobs use to
+                   complete a patch. These configurations include
+                   instance filter, package repository settings, and a
+                   schedule. For more information about creating and
+                   managing patch deployments, see [Scheduling patch
+                   jobs](\ https://cloud.google.com/compute/docs/os-patch-management/schedule-patch-jobs).
 
         """
         # Create or coerce a protobuf request object.
@@ -909,10 +897,8 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, patch_deployments.GetPatchDeploymentRequest):
             request = patch_deployments.GetPatchDeploymentRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -944,16 +930,16 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         r"""Get a page of OS Config patch deployments.
 
         Args:
-            request (:class:`~.patch_deployments.ListPatchDeploymentsRequest`):
+            request (google.cloud.osconfig_v1.types.ListPatchDeploymentsRequest):
                 The request object. A request message for listing patch
                 deployments.
-            parent (:class:`str`):
+            parent (str):
                 Required. The resource name of the parent in the form
                 ``projects/*``.
+
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -961,7 +947,7 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
                 sent along with the request as metadata.
 
         Returns:
-            ~.pagers.ListPatchDeploymentsPager:
+            google.cloud.osconfig_v1.services.os_config_service.pagers.ListPatchDeploymentsPager:
                 A response message for listing patch
                 deployments.
                 Iterating over this object will yield
@@ -985,10 +971,8 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, patch_deployments.ListPatchDeploymentsRequest):
             request = patch_deployments.ListPatchDeploymentsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -1026,16 +1010,16 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         r"""Delete an OS Config patch deployment.
 
         Args:
-            request (:class:`~.patch_deployments.DeletePatchDeploymentRequest`):
+            request (google.cloud.osconfig_v1.types.DeletePatchDeploymentRequest):
                 The request object. A request message for deleting a
                 patch deployment.
-            name (:class:`str`):
+            name (str):
                 Required. The resource name of the patch deployment in
                 the form ``projects/*/patchDeployments/*``.
+
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1058,10 +1042,8 @@ class OsConfigServiceClient(metaclass=OsConfigServiceClientMeta):
         # there are no flattened fields.
         if not isinstance(request, patch_deployments.DeletePatchDeploymentRequest):
             request = patch_deployments.DeletePatchDeploymentRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
