@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,8 +13,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
-from typing import Any, AsyncIterable, Awaitable, Callable, Iterable, Sequence, Tuple
+from typing import (
+    Any,
+    AsyncIterable,
+    Awaitable,
+    Callable,
+    Iterable,
+    Sequence,
+    Tuple,
+    Optional,
+)
 
 from google.cloud.osconfig_v1.types import patch_deployments
 from google.cloud.osconfig_v1.types import patch_jobs
@@ -25,7 +32,7 @@ class ListPatchJobsPager:
     """A pager for iterating through ``list_patch_jobs`` requests.
 
     This class thinly wraps an initial
-    :class:`~.patch_jobs.ListPatchJobsResponse` object, and
+    :class:`google.cloud.osconfig_v1.types.ListPatchJobsResponse` object, and
     provides an ``__iter__`` method to iterate through its
     ``patch_jobs`` field.
 
@@ -34,7 +41,7 @@ class ListPatchJobsPager:
     through the ``patch_jobs`` field on the
     corresponding responses.
 
-    All the usual :class:`~.patch_jobs.ListPatchJobsResponse`
+    All the usual :class:`google.cloud.osconfig_v1.types.ListPatchJobsResponse`
     attributes are available on the pager. If multiple requests are made, only
     the most recent response is retained, and thus used for attribute lookup.
     """
@@ -52,9 +59,9 @@ class ListPatchJobsPager:
         Args:
             method (Callable): The method that was originally called, and
                 which instantiated this pager.
-            request (:class:`~.patch_jobs.ListPatchJobsRequest`):
+            request (google.cloud.osconfig_v1.types.ListPatchJobsRequest):
                 The initial request object.
-            response (:class:`~.patch_jobs.ListPatchJobsResponse`):
+            response (google.cloud.osconfig_v1.types.ListPatchJobsResponse):
                 The initial response object.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
                 sent along with the request as metadata.
@@ -87,7 +94,7 @@ class ListPatchJobsAsyncPager:
     """A pager for iterating through ``list_patch_jobs`` requests.
 
     This class thinly wraps an initial
-    :class:`~.patch_jobs.ListPatchJobsResponse` object, and
+    :class:`google.cloud.osconfig_v1.types.ListPatchJobsResponse` object, and
     provides an ``__aiter__`` method to iterate through its
     ``patch_jobs`` field.
 
@@ -96,7 +103,7 @@ class ListPatchJobsAsyncPager:
     through the ``patch_jobs`` field on the
     corresponding responses.
 
-    All the usual :class:`~.patch_jobs.ListPatchJobsResponse`
+    All the usual :class:`google.cloud.osconfig_v1.types.ListPatchJobsResponse`
     attributes are available on the pager. If multiple requests are made, only
     the most recent response is retained, and thus used for attribute lookup.
     """
@@ -109,14 +116,14 @@ class ListPatchJobsAsyncPager:
         *,
         metadata: Sequence[Tuple[str, str]] = ()
     ):
-        """Instantiate the pager.
+        """Instantiates the pager.
 
         Args:
             method (Callable): The method that was originally called, and
                 which instantiated this pager.
-            request (:class:`~.patch_jobs.ListPatchJobsRequest`):
+            request (google.cloud.osconfig_v1.types.ListPatchJobsRequest):
                 The initial request object.
-            response (:class:`~.patch_jobs.ListPatchJobsResponse`):
+            response (google.cloud.osconfig_v1.types.ListPatchJobsResponse):
                 The initial response object.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
                 sent along with the request as metadata.
@@ -153,7 +160,7 @@ class ListPatchJobInstanceDetailsPager:
     """A pager for iterating through ``list_patch_job_instance_details`` requests.
 
     This class thinly wraps an initial
-    :class:`~.patch_jobs.ListPatchJobInstanceDetailsResponse` object, and
+    :class:`google.cloud.osconfig_v1.types.ListPatchJobInstanceDetailsResponse` object, and
     provides an ``__iter__`` method to iterate through its
     ``patch_job_instance_details`` field.
 
@@ -162,7 +169,7 @@ class ListPatchJobInstanceDetailsPager:
     through the ``patch_job_instance_details`` field on the
     corresponding responses.
 
-    All the usual :class:`~.patch_jobs.ListPatchJobInstanceDetailsResponse`
+    All the usual :class:`google.cloud.osconfig_v1.types.ListPatchJobInstanceDetailsResponse`
     attributes are available on the pager. If multiple requests are made, only
     the most recent response is retained, and thus used for attribute lookup.
     """
@@ -180,9 +187,9 @@ class ListPatchJobInstanceDetailsPager:
         Args:
             method (Callable): The method that was originally called, and
                 which instantiated this pager.
-            request (:class:`~.patch_jobs.ListPatchJobInstanceDetailsRequest`):
+            request (google.cloud.osconfig_v1.types.ListPatchJobInstanceDetailsRequest):
                 The initial request object.
-            response (:class:`~.patch_jobs.ListPatchJobInstanceDetailsResponse`):
+            response (google.cloud.osconfig_v1.types.ListPatchJobInstanceDetailsResponse):
                 The initial response object.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
                 sent along with the request as metadata.
@@ -215,7 +222,7 @@ class ListPatchJobInstanceDetailsAsyncPager:
     """A pager for iterating through ``list_patch_job_instance_details`` requests.
 
     This class thinly wraps an initial
-    :class:`~.patch_jobs.ListPatchJobInstanceDetailsResponse` object, and
+    :class:`google.cloud.osconfig_v1.types.ListPatchJobInstanceDetailsResponse` object, and
     provides an ``__aiter__`` method to iterate through its
     ``patch_job_instance_details`` field.
 
@@ -224,7 +231,7 @@ class ListPatchJobInstanceDetailsAsyncPager:
     through the ``patch_job_instance_details`` field on the
     corresponding responses.
 
-    All the usual :class:`~.patch_jobs.ListPatchJobInstanceDetailsResponse`
+    All the usual :class:`google.cloud.osconfig_v1.types.ListPatchJobInstanceDetailsResponse`
     attributes are available on the pager. If multiple requests are made, only
     the most recent response is retained, and thus used for attribute lookup.
     """
@@ -239,14 +246,14 @@ class ListPatchJobInstanceDetailsAsyncPager:
         *,
         metadata: Sequence[Tuple[str, str]] = ()
     ):
-        """Instantiate the pager.
+        """Instantiates the pager.
 
         Args:
             method (Callable): The method that was originally called, and
                 which instantiated this pager.
-            request (:class:`~.patch_jobs.ListPatchJobInstanceDetailsRequest`):
+            request (google.cloud.osconfig_v1.types.ListPatchJobInstanceDetailsRequest):
                 The initial request object.
-            response (:class:`~.patch_jobs.ListPatchJobInstanceDetailsResponse`):
+            response (google.cloud.osconfig_v1.types.ListPatchJobInstanceDetailsResponse):
                 The initial response object.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
                 sent along with the request as metadata.
@@ -285,7 +292,7 @@ class ListPatchDeploymentsPager:
     """A pager for iterating through ``list_patch_deployments`` requests.
 
     This class thinly wraps an initial
-    :class:`~.patch_deployments.ListPatchDeploymentsResponse` object, and
+    :class:`google.cloud.osconfig_v1.types.ListPatchDeploymentsResponse` object, and
     provides an ``__iter__`` method to iterate through its
     ``patch_deployments`` field.
 
@@ -294,7 +301,7 @@ class ListPatchDeploymentsPager:
     through the ``patch_deployments`` field on the
     corresponding responses.
 
-    All the usual :class:`~.patch_deployments.ListPatchDeploymentsResponse`
+    All the usual :class:`google.cloud.osconfig_v1.types.ListPatchDeploymentsResponse`
     attributes are available on the pager. If multiple requests are made, only
     the most recent response is retained, and thus used for attribute lookup.
     """
@@ -312,9 +319,9 @@ class ListPatchDeploymentsPager:
         Args:
             method (Callable): The method that was originally called, and
                 which instantiated this pager.
-            request (:class:`~.patch_deployments.ListPatchDeploymentsRequest`):
+            request (google.cloud.osconfig_v1.types.ListPatchDeploymentsRequest):
                 The initial request object.
-            response (:class:`~.patch_deployments.ListPatchDeploymentsResponse`):
+            response (google.cloud.osconfig_v1.types.ListPatchDeploymentsResponse):
                 The initial response object.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
                 sent along with the request as metadata.
@@ -347,7 +354,7 @@ class ListPatchDeploymentsAsyncPager:
     """A pager for iterating through ``list_patch_deployments`` requests.
 
     This class thinly wraps an initial
-    :class:`~.patch_deployments.ListPatchDeploymentsResponse` object, and
+    :class:`google.cloud.osconfig_v1.types.ListPatchDeploymentsResponse` object, and
     provides an ``__aiter__`` method to iterate through its
     ``patch_deployments`` field.
 
@@ -356,7 +363,7 @@ class ListPatchDeploymentsAsyncPager:
     through the ``patch_deployments`` field on the
     corresponding responses.
 
-    All the usual :class:`~.patch_deployments.ListPatchDeploymentsResponse`
+    All the usual :class:`google.cloud.osconfig_v1.types.ListPatchDeploymentsResponse`
     attributes are available on the pager. If multiple requests are made, only
     the most recent response is retained, and thus used for attribute lookup.
     """
@@ -371,14 +378,14 @@ class ListPatchDeploymentsAsyncPager:
         *,
         metadata: Sequence[Tuple[str, str]] = ()
     ):
-        """Instantiate the pager.
+        """Instantiates the pager.
 
         Args:
             method (Callable): The method that was originally called, and
                 which instantiated this pager.
-            request (:class:`~.patch_deployments.ListPatchDeploymentsRequest`):
+            request (google.cloud.osconfig_v1.types.ListPatchDeploymentsRequest):
                 The initial request object.
-            response (:class:`~.patch_deployments.ListPatchDeploymentsResponse`):
+            response (google.cloud.osconfig_v1.types.ListPatchDeploymentsResponse):
                 The initial response object.
             metadata (Sequence[Tuple[str, str]]): Strings which should be
                 sent along with the request as metadata.
