@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,21 +13,21 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import abc
-import typing
+from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
+import packaging.version
 import pkg_resources
 
-from google import auth  # type: ignore
-from google.api_core import exceptions  # type: ignore
+import google.auth  # type: ignore
+import google.api_core  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 
 from google.cloud.osconfig_v1.types import patch_deployments
 from google.cloud.osconfig_v1.types import patch_jobs
-from google.protobuf import empty_pb2 as empty  # type: ignore
-
+from google.protobuf import empty_pb2  # type: ignore
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
@@ -37,27 +36,41 @@ try:
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
 
+try:
+    # google.auth.__version__ was added in 1.26.0
+    _GOOGLE_AUTH_VERSION = google.auth.__version__
+except AttributeError:
+    try:  # try pkg_resources if it is available
+        _GOOGLE_AUTH_VERSION = pkg_resources.get_distribution("google-auth").version
+    except pkg_resources.DistributionNotFound:  # pragma: NO COVER
+        _GOOGLE_AUTH_VERSION = None
+
+_API_CORE_VERSION = google.api_core.__version__
+
 
 class OsConfigServiceTransport(abc.ABC):
     """Abstract transport class for OsConfigService."""
 
     AUTH_SCOPES = ("https://www.googleapis.com/auth/cloud-platform",)
 
+    DEFAULT_HOST: str = "osconfig.googleapis.com"
+
     def __init__(
         self,
         *,
-        host: str = "osconfig.googleapis.com",
-        credentials: credentials.Credentials = None,
-        credentials_file: typing.Optional[str] = None,
-        scopes: typing.Optional[typing.Sequence[str]] = AUTH_SCOPES,
-        quota_project_id: typing.Optional[str] = None,
+        host: str = DEFAULT_HOST,
+        credentials: ga_credentials.Credentials = None,
+        credentials_file: Optional[str] = None,
+        scopes: Optional[Sequence[str]] = None,
+        quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
         **kwargs,
     ) -> None:
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -66,13 +79,13 @@ class OsConfigServiceTransport(abc.ABC):
             credentials_file (Optional[str]): A file with credentials that can
                 be loaded with :func:`google.auth.load_credentials_from_file`.
                 This argument is mutually exclusive with credentials.
-            scope (Optional[Sequence[str]]): A list of scopes.
+            scopes (Optional[Sequence[str]]): A list of scopes.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
         """
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
@@ -80,28 +93,75 @@ class OsConfigServiceTransport(abc.ABC):
             host += ":443"
         self._host = host
 
+        scopes_kwargs = self._get_scopes_kwargs(self._host, scopes)
+
+        # Save the scopes.
+        self._scopes = scopes or self.AUTH_SCOPES
+
         # If no credentials are provided, then determine the appropriate
         # defaults.
         if credentials and credentials_file:
-            raise exceptions.DuplicateCredentialArgs(
+            raise core_exceptions.DuplicateCredentialArgs(
                 "'credentials_file' and 'credentials' are mutually exclusive"
             )
 
         if credentials_file is not None:
-            credentials, _ = auth.load_credentials_from_file(
-                credentials_file, scopes=scopes, quota_project_id=quota_project_id
+            credentials, _ = google.auth.load_credentials_from_file(
+                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
             )
 
         elif credentials is None:
-            credentials, _ = auth.default(
-                scopes=scopes, quota_project_id=quota_project_id
+            credentials, _ = google.auth.default(
+                **scopes_kwargs, quota_project_id=quota_project_id
             )
 
         # Save the credentials.
         self._credentials = credentials
 
-        # Lifted into its own function so it can be stubbed out during tests.
-        self._prep_wrapped_messages(client_info)
+    # TODO(busunkim): These two class methods are in the base transport
+    # to avoid duplicating code across the transport classes. These functions
+    # should be deleted once the minimum required versions of google-api-core
+    # and google-auth are increased.
+
+    # TODO: Remove this function once google-auth >= 1.25.0 is required
+    @classmethod
+    def _get_scopes_kwargs(
+        cls, host: str, scopes: Optional[Sequence[str]]
+    ) -> Dict[str, Optional[Sequence[str]]]:
+        """Returns scopes kwargs to pass to google-auth methods depending on the google-auth version"""
+
+        scopes_kwargs = {}
+
+        if _GOOGLE_AUTH_VERSION and (
+            packaging.version.parse(_GOOGLE_AUTH_VERSION)
+            >= packaging.version.parse("1.25.0")
+        ):
+            scopes_kwargs = {"scopes": scopes, "default_scopes": cls.AUTH_SCOPES}
+        else:
+            scopes_kwargs = {"scopes": scopes or cls.AUTH_SCOPES}
+
+        return scopes_kwargs
+
+    # TODO: Remove this function once google-api-core >= 1.26.0 is required
+    @classmethod
+    def _get_self_signed_jwt_kwargs(
+        cls, host: str, scopes: Optional[Sequence[str]]
+    ) -> Dict[str, Union[Optional[Sequence[str]], str]]:
+        """Returns kwargs to pass to grpc_helpers.create_channel depending on the google-api-core version"""
+
+        self_signed_jwt_kwargs: Dict[str, Union[Optional[Sequence[str]], str]] = {}
+
+        if _API_CORE_VERSION and (
+            packaging.version.parse(_API_CORE_VERSION)
+            >= packaging.version.parse("1.26.0")
+        ):
+            self_signed_jwt_kwargs["default_scopes"] = cls.AUTH_SCOPES
+            self_signed_jwt_kwargs["scopes"] = scopes
+            self_signed_jwt_kwargs["default_host"] = cls.DEFAULT_HOST
+        else:
+            self_signed_jwt_kwargs["scopes"] = scopes or cls.AUTH_SCOPES
+
+        return self_signed_jwt_kwargs
 
     def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
@@ -148,38 +208,38 @@ class OsConfigServiceTransport(abc.ABC):
     @property
     def execute_patch_job(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [patch_jobs.ExecutePatchJobRequest],
-        typing.Union[patch_jobs.PatchJob, typing.Awaitable[patch_jobs.PatchJob]],
+        Union[patch_jobs.PatchJob, Awaitable[patch_jobs.PatchJob]],
     ]:
         raise NotImplementedError()
 
     @property
     def get_patch_job(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [patch_jobs.GetPatchJobRequest],
-        typing.Union[patch_jobs.PatchJob, typing.Awaitable[patch_jobs.PatchJob]],
+        Union[patch_jobs.PatchJob, Awaitable[patch_jobs.PatchJob]],
     ]:
         raise NotImplementedError()
 
     @property
     def cancel_patch_job(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [patch_jobs.CancelPatchJobRequest],
-        typing.Union[patch_jobs.PatchJob, typing.Awaitable[patch_jobs.PatchJob]],
+        Union[patch_jobs.PatchJob, Awaitable[patch_jobs.PatchJob]],
     ]:
         raise NotImplementedError()
 
     @property
     def list_patch_jobs(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [patch_jobs.ListPatchJobsRequest],
-        typing.Union[
+        Union[
             patch_jobs.ListPatchJobsResponse,
-            typing.Awaitable[patch_jobs.ListPatchJobsResponse],
+            Awaitable[patch_jobs.ListPatchJobsResponse],
         ],
     ]:
         raise NotImplementedError()
@@ -187,11 +247,11 @@ class OsConfigServiceTransport(abc.ABC):
     @property
     def list_patch_job_instance_details(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [patch_jobs.ListPatchJobInstanceDetailsRequest],
-        typing.Union[
+        Union[
             patch_jobs.ListPatchJobInstanceDetailsResponse,
-            typing.Awaitable[patch_jobs.ListPatchJobInstanceDetailsResponse],
+            Awaitable[patch_jobs.ListPatchJobInstanceDetailsResponse],
         ],
     ]:
         raise NotImplementedError()
@@ -199,11 +259,11 @@ class OsConfigServiceTransport(abc.ABC):
     @property
     def create_patch_deployment(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [patch_deployments.CreatePatchDeploymentRequest],
-        typing.Union[
+        Union[
             patch_deployments.PatchDeployment,
-            typing.Awaitable[patch_deployments.PatchDeployment],
+            Awaitable[patch_deployments.PatchDeployment],
         ],
     ]:
         raise NotImplementedError()
@@ -211,11 +271,11 @@ class OsConfigServiceTransport(abc.ABC):
     @property
     def get_patch_deployment(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [patch_deployments.GetPatchDeploymentRequest],
-        typing.Union[
+        Union[
             patch_deployments.PatchDeployment,
-            typing.Awaitable[patch_deployments.PatchDeployment],
+            Awaitable[patch_deployments.PatchDeployment],
         ],
     ]:
         raise NotImplementedError()
@@ -223,11 +283,11 @@ class OsConfigServiceTransport(abc.ABC):
     @property
     def list_patch_deployments(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [patch_deployments.ListPatchDeploymentsRequest],
-        typing.Union[
+        Union[
             patch_deployments.ListPatchDeploymentsResponse,
-            typing.Awaitable[patch_deployments.ListPatchDeploymentsResponse],
+            Awaitable[patch_deployments.ListPatchDeploymentsResponse],
         ],
     ]:
         raise NotImplementedError()
@@ -235,9 +295,9 @@ class OsConfigServiceTransport(abc.ABC):
     @property
     def delete_patch_deployment(
         self,
-    ) -> typing.Callable[
+    ) -> Callable[
         [patch_deployments.DeletePatchDeploymentRequest],
-        typing.Union[empty.Empty, typing.Awaitable[empty.Empty]],
+        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
     ]:
         raise NotImplementedError()
 
